package com.ruoyi.szxc.service;

import com.ruoyi.szxc.domain.SzxcPersonTag;

import java.util.List;

/**
 * 人员标签Service接口
 * 
 * @author hs
 * @date 2024-03-14
 */
public interface ISzxcPersonTagService 
{
    /**
     * 查询人员标签
     * 
     * @param id 人员标签主键
     * @return 人员标签
     */
    public SzxcPersonTag selectSzxcPersonTagById(Long id);

    /**
     * 查询人员标签列表
     * 
     * @param szxcPersonTag 人员标签
     * @return 人员标签集合
     */

    public List<SzxcPersonTag> selectSzxcPersonTagList(SzxcPersonTag szxcPersonTag);

    /**
     * 新增人员标签
     * 
     * @param szxcPersonTag 人员标签
     * @return 结果
     */
    public int insertSzxcPersonTag(SzxcPersonTag szxcPersonTag);

    /**
     * 修改人员标签
     * 
     * @param szxcPersonTag 人员标签
     * @return 结果
     */
    public int updateSzxcPersonTag(SzxcPersonTag szxcPersonTag);

    /**
     * 批量删除人员标签
     * 
     * @param ids 需要删除的人员标签主键集合
     * @return 结果
     */
    public int deleteSzxcPersonTagByIds(Long[] ids);

    /**
     * 删除人员标签信息
     * 
     * @param id 人员标签主键
     * @return 结果
     */
    public int deleteSzxcPersonTagById(Long id);
}
