package com.ruoyi.szxc.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.szxc.domain.SzxcPersonTag;
import com.ruoyi.szxc.service.ISzxcPersonTagService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 人员标签Controller
 * 
 * @author hs
 * @date 2024-03-14
 */
@RestController
@RequestMapping("/szxc/tag")
public class SzxcPersonTagController extends BaseController
{
    @Autowired
    private ISzxcPersonTagService szxcPersonTagService;

    /**
     * 查询人员标签列表
     */
    @PreAuthorize("@ss.hasPermi('szxc:tag:list')")
    @GetMapping("/list")
    public TableDataInfo list(SzxcPersonTag szxcPersonTag)
    {
        startPage();
        List<SzxcPersonTag> list = szxcPersonTagService.selectSzxcPersonTagList(szxcPersonTag);
        return getDataTable(list);
    }

    /**
     * 导出人员标签列表
     */
    @PreAuthorize("@ss.hasPermi('szxc:tag:export')")
    @Log(title = "人员标签", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SzxcPersonTag szxcPersonTag)
    {
        List<SzxcPersonTag> list = szxcPersonTagService.selectSzxcPersonTagList(szxcPersonTag);
        ExcelUtil<SzxcPersonTag> util = new ExcelUtil<SzxcPersonTag>(SzxcPersonTag.class);
        util.exportExcel(response, list, "人员标签数据");
    }

    /**
     * 获取人员标签详细信息
     */
    @PreAuthorize("@ss.hasPermi('szxc:tag:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(szxcPersonTagService.selectSzxcPersonTagById(id));
    }

    /**
     * 新增人员标签
     */
    @PreAuthorize("@ss.hasPermi('szxc:tag:add')")
    @Log(title = "人员标签", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SzxcPersonTag szxcPersonTag)
    {
        //根据前端传递过来的部门存储，如果没传则存储当前用户的部门
        if(szxcPersonTag.getDeptId()==null){
            szxcPersonTag.setDeptId(getDeptId());
        }
        szxcPersonTag.setUserId(getUserId());
        return toAjax(szxcPersonTagService.insertSzxcPersonTag(szxcPersonTag));
    }

    /**
     * 修改人员标签
     */
    @PreAuthorize("@ss.hasPermi('szxc:tag:edit')")
    @Log(title = "人员标签", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SzxcPersonTag szxcPersonTag)
    {
        return toAjax(szxcPersonTagService.updateSzxcPersonTag(szxcPersonTag));
    }

    /**
     * 删除人员标签
     */
    @PreAuthorize("@ss.hasPermi('szxc:tag:remove')")
    @Log(title = "人员标签", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(szxcPersonTagService.deleteSzxcPersonTagByIds(ids));
    }
}
